@@ -198,20 +198,20 @@ KcmGtk::KcmGtk(TQWidget *parent, const char *name, const TQStringList&)
 	load();
 	
 	// Connect some signals
-	connect(widget->warning2, TQT_SIGNAL(leftClickedURL(const TQString&)), TDEApplication::kApplication(), TQT_SLOT(invokeBrowser(const TQString&)));
-	connect(widget->styleGroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(itemChanged()));
-	connect(widget->warning5, TQT_SIGNAL(leftClickedURL(const TQString&)), TDEApplication::kApplication(), TQT_SLOT(invokeBrowser(const TQString&)));
-	connect(widget->styleGroup3, TQT_SIGNAL(clicked(int)), TQT_SLOT(itemChanged()));
-	connect(widget->fontGroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(itemChanged()));
-	connect(widget->styleBox, TQT_SIGNAL(activated(int)), TQT_SLOT(itemChanged()));
-	connect(widget->styleBox, TQT_SIGNAL(activated(int)), TQT_SLOT(styleChanged()));
-	connect(widget->styleBox3, TQT_SIGNAL(activated(int)), TQT_SLOT(itemChanged()));
-	connect(widget->styleBox3, TQT_SIGNAL(activated(int)), TQT_SLOT(styleChanged()));
-	connect(widget->emacsBox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(itemChanged()));
-	connect(widget->fontChange, TQT_SIGNAL(clicked()), TQT_SLOT(fontChangeClicked()));
-	connect(widget->emacsDetails, TQT_SIGNAL(clicked()), TQT_SLOT(emacsDetailsClicked()));
-	connect(widget->warning3, TQT_SIGNAL(clicked()), TQT_SLOT(searchPathsClicked()));
-	connect(widget->warning6, TQT_SIGNAL(clicked()), TQT_SLOT(searchPathsClicked()));
+	connect(widget->warning2, TQ_SIGNAL(leftClickedURL(const TQString&)), TDEApplication::kApplication(), TQ_SLOT(invokeBrowser(const TQString&)));
+	connect(widget->styleGroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(itemChanged()));
+	connect(widget->warning5, TQ_SIGNAL(leftClickedURL(const TQString&)), TDEApplication::kApplication(), TQ_SLOT(invokeBrowser(const TQString&)));
+	connect(widget->styleGroup3, TQ_SIGNAL(clicked(int)), TQ_SLOT(itemChanged()));
+	connect(widget->fontGroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(itemChanged()));
+	connect(widget->styleBox, TQ_SIGNAL(activated(int)), TQ_SLOT(itemChanged()));
+	connect(widget->styleBox, TQ_SIGNAL(activated(int)), TQ_SLOT(styleChanged()));
+	connect(widget->styleBox3, TQ_SIGNAL(activated(int)), TQ_SLOT(itemChanged()));
+	connect(widget->styleBox3, TQ_SIGNAL(activated(int)), TQ_SLOT(styleChanged()));
+	connect(widget->emacsBox, TQ_SIGNAL(toggled(bool)), TQ_SLOT(itemChanged()));
+	connect(widget->fontChange, TQ_SIGNAL(clicked()), TQ_SLOT(fontChangeClicked()));
+	connect(widget->emacsDetails, TQ_SIGNAL(clicked()), TQ_SLOT(emacsDetailsClicked()));
+	connect(widget->warning3, TQ_SIGNAL(clicked()), TQ_SLOT(searchPathsClicked()));
+	connect(widget->warning6, TQ_SIGNAL(clicked()), TQ_SLOT(searchPathsClicked()));
 }
 
 void KcmGtk::getInstalledThemes()
@@ -464,7 +464,7 @@ void KcmGtk::save()
 	bool envFileDidNotExist = (!file.exists());
 	
 	file.open(IO_ReadWrite);
-	stream.setDevice(TQT_TQIODEVICE(&file));
+	stream.setDevice(&file);
 	bool found = false;
 	for (;;)
 	{
@@ -514,7 +514,7 @@ void KcmGtk::save()
 	if (file.exists())
 	{
 		file.open(IO_ReadOnly);
-		stream.setDevice(TQT_TQIODEVICE(&file));
+		stream.setDevice(&file);
 		TQString fileDataString = stream.read();
 		file.close();
 
@@ -522,7 +522,7 @@ void KcmGtk::save()
 		fileDataString.replace("\n" + rcLine, "\n# (This is no longer needed from version 0.8 of the theme engine)\n# " + rcLine);
 
 		file.open(IO_WriteOnly);
-		stream.setDevice(TQT_TQIODEVICE(&file));
+		stream.setDevice(&file);
 		stream << fileDataString;
 		file.close();
 	}
@@ -576,11 +576,11 @@ void KcmGtk::searchPathsClicked()
 	if (searchPathsDialog == NULL)
 	{
 		searchPathsDialog = new SearchPaths(this);
-		connect(searchPathsDialog->okButton, TQT_SIGNAL(clicked()), TQT_SLOT(searchPathsOk()));
-		connect(searchPathsDialog->pathBox, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(searchPathsTextChanged(const TQString&)));
-		connect(searchPathsDialog->pathList, TQT_SIGNAL(currentChanged(TQListBoxItem*)), TQT_SLOT(searchPathsCurrentChanged(TQListBoxItem*)));
-		connect(searchPathsDialog->addButton, TQT_SIGNAL(clicked()), TQT_SLOT(searchPathsAddClicked()));
-		connect(searchPathsDialog->removeButton, TQT_SIGNAL(clicked()), TQT_SLOT(searchPathsRemoveClicked()));
+		connect(searchPathsDialog->okButton, TQ_SIGNAL(clicked()), TQ_SLOT(searchPathsOk()));
+		connect(searchPathsDialog->pathBox, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(searchPathsTextChanged(const TQString&)));
+		connect(searchPathsDialog->pathList, TQ_SIGNAL(currentChanged(TQListBoxItem*)), TQ_SLOT(searchPathsCurrentChanged(TQListBoxItem*)));
+		connect(searchPathsDialog->addButton, TQ_SIGNAL(clicked()), TQ_SLOT(searchPathsAddClicked()));
+		connect(searchPathsDialog->removeButton, TQ_SIGNAL(clicked()), TQ_SLOT(searchPathsRemoveClicked()));
 	}
 
 	searchPathsDialog->pathList->clear();
